==> nextcloud-31.0.2-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/pt_BR.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "O operador fornecido é inválido",
    "The given regular expression is invalid" : "A expressão regular fornecida é inválida",
    "The given file size is invalid" : "O tamanho fornecido do arquivo é inválido",
    "The given tag id is invalid" : "O id da etiqueta fornecida é inválido",
    "The given IP range is invalid" : "O intervalo de IP fornecido é inválido",
    "The given IP range is not valid for IPv4" : "O intervalo de IP fornecido é inválido para IPv4",
    "The given IP range is not valid for IPv6" : "O range de IP fornecido é inválido para IPv6",
    "The given time span is invalid" : "O intervalo de tempo fornecido é inválido",
    "The given start time is invalid" : "O horário de início fornecido é inválido",
    "The given end time is invalid" : "O horário de término fornecido é inválido",
    "The given group does not exist" : "O grupo fornecido não existe",
    "File" : "Arquivo",
    "File created" : "Arquivo criado",
    "File updated" : "Arquivo atualizado",
    "File renamed" : "Arquivo renomeado",
    "File deleted" : "Arquivo apagado",
    "File accessed" : "Arquivo acessado",
    "File copied" : "Arquivo copiado",
    "Tag assigned" : "Etiqueta atribuída",
    "Someone" : "Alguém",
    "%s created %s" : "%s criou %s",
    "%s modified %s" : "%s modificou %s",
    "%s deleted %s" : "%s excluiu %s",
    "%s accessed %s" : "%s acessou %s",
    "%s renamed %s" : "%s renomeado %s",
    "%s copied %s" : "%s copiou %s",
    "%s assigned %s to %s" : "%s atribuiu %s para %s",
    "Operation #%s does not exist" : "Operação #%s não existe",
    "Entity %s does not exist" : "Entidade %s não existe",
    "Entity %s is invalid" : "Entidade %s é inválida",
    "No events are chosen." : "Nenhum evento escolhido.",
    "Entity %s has no event %s" : "Entidade %s não tem evento %s",
    "Operation %s does not exist" : "Operação %s não existe",
    "Operation %s is invalid" : "Operação %s é inválida",
    "At least one check needs to be provided" : "É necessário fornecer ao menos uma verificação",
    "The provided operation data is too long" : "Os dados de operação fornecidos são muito longos",
    "Invalid check provided" : "Verificação fornecida inválida",
    "Check %s does not exist" : "Verifique se %s não existe",
    "Check %s is invalid" : "Verifique se %s é inválido",
    "Check %s is not allowed with this entity" : "Verificação de %s não é permitida nesta entidade",
    "The provided check value is too long" : "O valor de verificação fornecido é muito longo",
    "Check #%s does not exist" : "Verifique se %s não existe",
    "Check %s is invalid or does not exist" : "Verifique se %s é valido ou existe",
    "Flow" : "Fluxo",
    "Nextcloud workflow engine" : "Mecanismo de fluxo de trabalho Nextcloud",
    "Select a filter" : "Selecionar um filtro",
    "Select a comparator" : "Selecionar um comparador",
    "Remove filter" : "Remover filtro",
    "Folder" : "Pasta",
    "Images" : "Imagens",
    "Office documents" : "Documentos Office",
    "PDF documents" : "Documentos PDF",
    "Custom MIME type" : "Tipo MIME personalizado",
    "Custom mimetype" : "Mimetype personalizado",
    "Select a file type" : "Selecionar um tipo de arquivo",
    "e.g. httpd/unix-directory" : "por ex. httpd/unix-directory",
    "Please enter a valid time span" : "Digite um período de tempo válido",
    "Files WebDAV" : "Arquivos WebDAV",
    "Custom URL" : "URL personalizada",
    "Select a request URL" : "Selecione uma URL de solicitação",
    "Android client" : "Cliente Android",
    "iOS client" : "Cliente iOS",
    "Desktop client" : "Cliente de Desktop",
    "Thunderbird & Outlook addons" : "Extensões para Thunderbird & Outlook",
    "Custom user agent" : "Agente do usuário personalizado",
    "Select a user agent" : "Selecione um agente de usuário",
    "Select groups" : "Selecionar grupos",
    "Groups" : "Grupos",
    "Type to search for group …" : "Digite para pesquisar o grupo…",
    "Select a trigger" : "Selecione um gatilho",
    "At least one event must be selected" : "É necessário selecionar ao menos um evento",
    "Add new flow" : "Adicionar novo fluxo",
    "The configuration is invalid" : "A configuração é inválida",
    "Active" : "Ativo",
    "Save" : "Salvar",
    "When" : "Quando",
    "and" : "e",
    "Add a new filter" : "Adicionar um novo filtro",
    "Cancel" : "Cancelar",
    "Delete" : "Excluir",
    "Available flows" : "Fluxos disponíveis",
    "For details on how to write your own flow, check out the development documentation." : "Para detalhes sobre como escrever seu próprio fluxo, consulte a documentação de desenvolvimento.",
    "No flows installed" : "Nenhum fluxo instalado",
    "Ask your administrator to install new flows." : "Peça ao seu administrador para instalar novos fluxos.",
    "More flows" : "Mais fluxos",
    "Browse the App Store" : "Navegar pela loja de aplicativos",
    "Show less" : "Mostrar menos",
    "Show more" : "Mostrar mais",
    "Configured flows" : "Fluxos configurados",
    "Your flows" : "Seus fluxos",
    "No flows configured" : "Nenhum fluxo configurado",
    "matches" : "coincide",
    "does not match" : "não coincide",
    "is" : "é",
    "is not" : "não é",
    "File name" : "Nome do arquivo",
    "File MIME type" : "Tipo de arquivo MIME",
    "File size (upload)" : "Tamanho do arquivo (envio)",
    "less" : "menor que",
    "less or equals" : "menor ou igual a",
    "greater or equals" : "maior ou igual a",
    "greater" : "maior que",
    "Request remote address" : "Endereço da requisição",
    "matches IPv4" : "IPv4 coincide",
    "does not match IPv4" : "IPV4 não coincide",
    "matches IPv6" : "IPV6 coincide",
    "does not match IPv6" : "IPV6 não coincide",
    "File system tag" : "Etiqueta do sistema de arquivos",
    "is tagged with" : "está etiquetado com",
    "is not tagged with" : "não está etiquetado com",
    "Request URL" : "URL da requisição",
    "Request time" : "Tempo de solicitação",
    "between" : "entre",
    "not between" : "não entre",
    "Request user agent" : "Agente de usuário da requisição",
    "Group membership" : "Associação ao grupo",
    "is member of" : "é membro de",
    "is not member of" : "não é membro de"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/pt_BR.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "O operador fornecido é inválido",
    "The given regular expression is invalid" : "A expressão regular fornecida é inválida",
    "The given file size is invalid" : "O tamanho fornecido do arquivo é inválido",
    "The given tag id is invalid" : "O id da etiqueta fornecida é inválido",
    "The given IP range is invalid" : "O intervalo de IP fornecido é inválido",
    "The given IP range is not valid for IPv4" : "O intervalo de IP fornecido é inválido para IPv4",
    "The given IP range is not valid for IPv6" : "O range de IP fornecido é inválido para IPv6",
    "The given time span is invalid" : "O intervalo de tempo fornecido é inválido",
    "The given start time is invalid" : "O horário de início fornecido é inválido",
    "The given end time is invalid" : "O horário de término fornecido é inválido",
    "The given group does not exist" : "O grupo fornecido não existe",
    "File" : "Arquivo",
    "File created" : "Arquivo criado",
    "File updated" : "Arquivo atualizado",
    "File renamed" : "Arquivo renomeado",
    "File deleted" : "Arquivo apagado",
    "File accessed" : "Arquivo acessado",
    "File copied" : "Arquivo copiado",
    "Tag assigned" : "Etiqueta atribuída",
    "Someone" : "Alguém",
    "%s created %s" : "%s criou %s",
    "%s modified %s" : "%s modificou %s",
    "%s deleted %s" : "%s excluiu %s",
    "%s accessed %s" : "%s acessou %s",
    "%s renamed %s" : "%s renomeado %s",
    "%s copied %s" : "%s copiou %s",
    "%1$s assigned %2$s to %3$s" : "%1$s designou %2$s para %3$s",
    "Operation #%s does not exist" : "Operação #%s não existe",
    "Entity %s is invalid" : "Entidade %s é inválida",
    "Entity %s does not exist" : "Entidade %s não existe",
    "No events are chosen." : "Nenhum evento escolhido.",
    "Entity %s has no event %s" : "Entidade %s não tem evento %s",
    "The provided operation data is too long" : "Os dados de operação fornecidos são muito longos",
    "Operation %s is invalid" : "Operação %s é inválida",
    "Operation %s does not exist" : "Operação %s não existe",
    "At least one check needs to be provided" : "É necessário fornecer ao menos uma verificação",
    "Invalid check provided" : "Verificação fornecida inválida",
    "The provided check value is too long" : "O valor de verificação fornecido é muito longo",
    "Check %s is invalid" : "Verifique se %s é inválido",
    "Check %s does not exist" : "Verifique se %s não existe",
    "Check %s is not allowed with this entity" : "Verificação de %s não é permitida nesta entidade",
    "Check #%s does not exist" : "Verifique se %s não existe",
    "Check %s is invalid or does not exist" : "Verifique se %s é valido ou existe",
    "Flow" : "Fluxo",
    "Nextcloud workflow engine" : "Mecanismo de fluxo de trabalho Nextcloud",
    "Select a filter" : "Selecionar um filtro",
    "Select a comparator" : "Selecionar um comparador",
    "Remove filter" : "Remover filtro",
    "Audio" : "Áudio",
    "Folder" : "Pasta",
    "Images" : "Imagens",
    "Office documents" : "Documentos Office",
    "PDF documents" : "Documentos PDF",
    "Video" : "Vídeo",
    "Custom MIME type" : "Tipo MIME personalizado",
    "Select a file type" : "Selecionar um tipo de arquivo",
    "e.g. httpd/unix-directory" : "por ex. httpd/unix-directory",
    "Please enter a valid time span" : "Digite um período de tempo válido",
    "Files WebDAV" : "Arquivos WebDAV",
    "Custom URL" : "URL personalizada",
    "Select a request URL" : "Selecione uma URL de solicitação",
    "Android client" : "Cliente Android",
    "iOS client" : "Cliente iOS",
    "Desktop client" : "Cliente de Desktop",
    "Thunderbird & Outlook addons" : "Extensões para Thunderbird & Outlook",
    "Custom user agent" : "Agente do usuário personalizado",
    "Select a user agent" : "Selecione um agente de usuário",
    "Select groups" : "Selecione grupos",
    "Groups" : "Grupos",
    "Type to search for group …" : "Digite para pesquisar por grupo …",
    "Select a trigger" : "Selecione um gatilho",
    "At least one event must be selected" : "É necessário selecionar ao menos um evento",
    "Add new flow" : "Adicionar novo fluxo",
    "The configuration is invalid" : "A configuração é inválida",
    "Active" : "Ativo",
    "Save" : "Salvar",
    "When" : "Quando",
    "and" : "e",
    "Add a new filter" : "Adicionar um novo filtro",
    "Cancel" : "Cancelar",
    "Delete" : "Excluir",
    "Available flows" : "Fluxos disponíveis",
    "For details on how to write your own flow, check out the development documentation." : "Para detalhes sobre como escrever seu próprio fluxo, consulte a documentação de desenvolvimento.",
    "No flows installed" : "Nenhum fluxo instalado",
    "Ask your administrator to install new flows." : "Peça ao seu administrador para instalar novos fluxos.",
    "More flows" : "Mais fluxos",
    "Browse the App Store" : "Navegar pela Loja de Aplicativos",
    "Show less" : "Mostrar menos",
    "Show more" : "Mostrar mais",
    "Configured flows" : "Fluxos configurados",
    "Your flows" : "Seus fluxos",
    "No flows configured" : "Nenhum fluxo configurado",
    "matches" : "corresponde",
    "does not match" : "não coincide",
    "is" : "é",
    "is not" : "não é",
    "File name" : "Nome do arquivo",
    "File MIME type" : "Tipo de arquivo MIME",
    "File size (upload)" : "Tamanho do arquivo (upload)",
    "less" : "menor que",
    "less or equals" : "menor ou igual a",
    "greater or equals" : "maior ou igual a",
    "greater" : "maior que",
    "Request remote address" : "Endereço da requisição",
    "matches IPv4" : "corresponde a IPv4",
    "does not match IPv4" : "não corresponde a IPv4",
    "matches IPv6" : "corresponde a IPv6",
    "does not match IPv6" : "não corresponde a IPv6",
    "File system tag" : "Etiqueta do sistema de arquivos",
    "is tagged with" : "está etiquetado com",
    "is not tagged with" : "não está etiquetado com",
    "Request URL" : "URL da requisição",
    "Request time" : "Tempo de solicitação",
    "between" : "entre",
    "not between" : "não entre",
    "Request user agent" : "Agente de usuário da requisição",
    "Group membership" : "Associação ao grupo",
    "is member of" : "é membro de",
    "is not member of" : "não é membro de",
    "Type to search for group …" : "Digite para pesquisar um grupo …"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
